@@ -1796,8 +1796,8 @@
   [actions addObjectsFromArray: [classInfo objectForKey: @"ExtraActions"]]; 
   
   // header file comments...
-  [headerFile appendString: @"/* All Rights reserved */\n\n"];
-  [sourceFile appendString: @"/* All Rights reserved */\n\n"];
+  [headerFile appendString: @"/* All rights reserved */\n\n"];
+  [sourceFile appendString: @"/* All rights reserved */\n\n"];
   [headerFile appendString: @"#include <AppKit/AppKit.h>\n\n"];
   [sourceFile appendString: @"#include <AppKit/AppKit.h>\n"];
   if ([[headerPath stringByDeletingLastPathComponent]
@@ -1908,12 +1908,12 @@
 		{
 		  if([self isKnownClass: className])
 		    {
-		      NSString *title = [NSString stringWithFormat: 
+		      NSString *title = [NSString stringWithFormat: @"%@",
 						    _(@"Reparsing Class")];
-		      NSString *msg = [NSString stringWithFormat: 
-						  _(@"This may break connections to "
-						    @"actions/outlets to instances of class '%@' "
-						    @"and it's subclasses.  Continue?"), 
+                      NSString *messageFormat = _(@"This may break connections to "
+                                                  @"actions/outlets to instances of class '%@' "
+                                                  @"and it's subclasses.  Continue?"); 
+                      NSString *msg = [NSString stringWithFormat: messageFormat,
 						className];
 		      NSInteger retval = NSRunAlertPanel(title, msg,_(@"OK"),_(@"Cancel"), nil, nil);
 
