@@ -28,7 +28,8 @@
 #define	INCLUDED_GormCustomClassInspector_h
 
 #include <AppKit/AppKit.h>
-#include <InterfaceBuilder/IBInspector.h>
+
+#include <InterfaceBuilder/InterfaceBuilder.h>
 
 @class GormClassManager;
 
@@ -39,7 +40,7 @@
   GormClassManager *_classManager;
   NSString *_currentSelectionClassName;
   NSString *_parentClassName;
-  int _rowToSelect;
+  NSUInteger _rowToSelect;
 }
 - (void) select: (id)sender;
 @end
