@@ -26,11 +26,13 @@
 #ifndef INCLUDED_GormDocument_h
 #define INCLUDED_GormDocument_h
 
-#include <AppKit/AppKit.h>
 #include <Foundation/Foundation.h>
-#include <GNUstepGUI/GSNibContainer.h>
+#include <AppKit/AppKit.h>
+
 #include <InterfaceBuilder/InterfaceBuilder.h>
 
+#include <GNUstepGUI/GSNibContainer.h>
+
 @class GormClassManager, GormClassEditor, GormObjectProxy, GormFilesOwner, 
   GormFilePrefsManager, GormDocumentWindow;
 
@@ -291,6 +293,16 @@
  */
 - (NSMenu *) windowsMenu;
 
+/**
+ * Sets the recent documents menu.
+ */
+- (void) setRecentDocumentsMenu: (NSMenu *)menu;
+
+/**
+ * Returns the menu which will be the recent documents menu for the document.
+ */
+- (NSMenu *) recentDocumentsMenu;
+
 /*** first responder/font manager ***/
 
 /**
@@ -411,6 +423,26 @@
  * Reactivate all of the editors...
  */
 - (void) reactivateEditors;
+
+/**
+ * Returns the name for the object...
+ */ 
+- (NSString*) nameForObject: (id)anObject;
+
+/**
+ * Returns the object for name.
+ */
+- (id) objectForName: (NSString*)name;
+
+/**
+ * Returns all names for all objects known to Gorm.
+ */
+- (NSArray *) objects;
+
+/**
+ * Add aConnector to the set of connectors in this document.
+ */ 
+- (void) addConnector: (id<IBConnectors>)aConnector;
 @end
 
 @interface GormDocument (MenuValidation)
