@@ -540,7 +540,14 @@ static NSImage  *fileImage = nil;
 {
   NSArray *old;
   BOOL newObject = NO;
-
+  /*
+  if ([self containsObject: anObject] &&
+      [anObject isKindOfClass: [NSWindow class]] == NO &&
+      [anObject isKindOfClass: [NSPanel class]] == NO)
+    {
+      return;
+    }
+  */
   // Modify the document whenever something is added...
   [self touch];
 
@@ -750,7 +757,15 @@ static NSImage  *fileImage = nil;
   else if ([anObject isKindOfClass: [NSMatrix class]])
     {
       // add all of the cells....
-      [self attachObjects: [anObject cells] toParent: anObject];
+      if ([[anObject cells] count] > 0) // && [anObject prototype] != nil)
+        {
+          [self attachObjects: [anObject cells] toParent: anObject];
+        }
+
+      if ([anObject prototype] != nil)
+        {
+          [self attachObject: [anObject prototype] toParent: anObject];
+        }
     }
   /*
    * If it's a simple NSView, add it and all of it's subviews.
@@ -1075,7 +1090,7 @@ static NSImage  *fileImage = nil;
 {
   NSEnumerator	*enumerator;
   NSMutableSet	*editorSet;
-  id		obj;
+  id<IBEditors>	obj;
   NSMutableData	*data;
   NSArchiver    *archiver;
 
@@ -1223,9 +1238,9 @@ static NSImage  *fileImage = nil;
 }
 
 /**
- * Deteach anObject from the document.
+ * Detach anObject from the document.  Optionally close the editor
  */
-- (void) detachObject: (id)anObject
+- (void) detachObject: (id)anObject closeEditor: (BOOL)close_editor
 {
   if([self containsObject: anObject])
     {
@@ -1236,7 +1251,11 @@ static NSImage  *fileImage = nil;
       id               parent = [self parentEditorForEditor: editor];
 
       // close the editor...
-      [editor close];
+      if (close_editor)
+        {
+          [editor close];
+        }
+      
       if([parent respondsToSelector: @selector(selectObjects:)])
 	{
 	  [parent selectObjects: [NSArray array]];
@@ -1331,28 +1350,48 @@ static NSImage  *fileImage = nil;
 	}
       
       // iterate over the list and remove any subordinate objects.
-      [self detachObjects: objs];
+      [self detachObjects: objs closeEditors: close_editor];
 
-      [self setSelectionFromEditor: nil]; // clear the selection.
+      if (close_editor)
+        {
+          [self setSelectionFromEditor: nil]; // clear the selection.
+        }
+      
       RELEASE(name); // retained at beginning of method...
       [self touch]; // set the document as modified
     }
 }
 
 /**
- * Detach every object in anArray from the document.
+ * Detach object from document.
+ */ 
+- (void) detachObject: (id)object
+{
+  [self detachObject: object closeEditor: YES];
+}
+
+/**
+ * Detach every object in anArray from the document.  Optionally closing editors.
  */
-- (void) detachObjects: (NSArray*)anArray
+- (void) detachObjects: (NSArray*)anArray closeEditors: (BOOL)close_editors
 {
   NSEnumerator  *enumerator = [anArray objectEnumerator];
   NSObject      *obj;
 
   while ((obj = [enumerator nextObject]) != nil)
     {
-      [self detachObject: obj];
+      [self detachObject: obj closeEditor: close_editors];
     }
 }
 
+/** 
+ * Detach all objects in array from the document.
+ */
+- (void) detachObjects: (NSArray *)array
+{
+  [self detachObjects: array closeEditors: YES];
+}
+
 /**
  * The path to where the .gorm file is saved.
  */
@@ -1532,7 +1571,7 @@ static NSImage  *fileImage = nil;
     }
   else
     {
-      [[[links lastObject] destination] activate];
+      [(id<IBEditors>)[[links lastObject] destination] activate];
       return [[links lastObject] destination];
     }
 }
@@ -1643,7 +1682,9 @@ static void _real_close(GormDocument *self,
 	      [[self window] setExcludedFromWindowsMenu: YES];
 	      [[self window] orderOut: self];
 	    }
-	  
+
+          [[NSApp mainMenu] close]; // close the menu during test...
+          
 	  enumerator = [nameTable objectEnumerator];
 	  while ((obj = [enumerator nextObject]) != nil)
 	    {
@@ -1673,6 +1714,8 @@ static void _real_close(GormDocument *self,
 	  NSEnumerator	*enumerator;
 	  id		obj;
 
+          [[NSApp mainMenu] display]; // bring the menu back...
+          
 	  enumerator = [hidden objectEnumerator];
 	  while ((obj = [enumerator nextObject]) != nil)
 	    {
@@ -2580,11 +2623,12 @@ static void _real_close(GormDocument *self,
   id<IBConnectors> c = nil;
   BOOL removed = YES;
   NSInteger retval = -1;
-  NSString *title = [NSString stringWithFormat: _(@"Modifying Class")];
+  NSString *title = [NSString stringWithFormat: @"%@",_(@"Modifying Class")];
   NSString *msg;
+  NSString *msgFormat = _(@"This will break all connections to "
+                          @"actions/outlets to instances of class '%@' and it's subclasses.  Continue?");
 
-  msg = [NSString stringWithFormat: _(@"This will break all connections to "
-    @"actions/outlets to instances of class '%@' and it's subclasses.  Continue?"), className];
+  msg = [NSString stringWithFormat: msgFormat, className];
 
   // ask the user if he/she wants to continue...
   retval = NSRunAlertPanel(title, msg,_(@"OK"),_(@"Cancel"), nil, nil);
@@ -2693,9 +2737,10 @@ static void _real_close(GormDocument *self,
   id<IBConnectors> c = nil;
   BOOL renamed = YES;
   NSInteger retval = -1;
-  NSString *title = [NSString stringWithFormat: _(@"Modifying Class")];
+  NSString *title = [NSString stringWithFormat: @"%@", _(@"Modifying Class")];
+  NSString *msgFormat = _(@"Change class name '%@' to '%@'.  Continue?");
   NSString *msg = [NSString stringWithFormat: 
-			      _(@"Change class name '%@' to '%@'.  Continue?"),
+                              msgFormat,
 			    className, newName];
 
   // ask the user if he/she wants to continue...
@@ -3550,7 +3595,7 @@ static void _real_close(GormDocument *self,
   while ((con = [enumerator nextObject]) != nil)
     {
       if ([[con source] isKindOfClass: [NSView class]] == NO)
-	[[con destination] activate];
+	[(id<IBEditors>)[con destination] activate];
     }
   [savedEditors removeAllObjects];
 }
