@@ -1,7 +1,8 @@
 /* All Rights reserved */
 
 #include <AppKit/AppKit.h>
-#include <InterfaceBuilder/IBInspector.h>
+
+#include <InterfaceBuilder/InterfaceBuilder.h>
 
 @interface GormNSSplitViewInspector : IBInspector
 {
