@@ -22,8 +22,9 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
+#include <Foundation/Foundation.h>
 #include <AppKit/AppKit.h>
-#include <Foundation/NSUserDefaults.h>
+
 #include <InterfaceBuilder/InterfaceBuilder.h>
 
 #include "GormGenericEditor.h"
