@@ -25,8 +25,7 @@
 #ifndef INCLUDED_NSColorWell_GormExtensions_h
 #define INCLUDED_NSColorWell_GormExtensions_h
 
-#include <AppKit/NSColor.h>
-#include <AppKit/NSColorWell.h>
+#include <AppKit/AppKit.h>
 
 @interface NSColorWell (GormExtensions)
 /**
