@@ -22,7 +22,8 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#include <Foundation/NSString.h>
+#include <Foundation/Foundation.h>
+
 #include <InterfaceBuilder/IBDocuments.h>
 
 NSString *IBDidOpenDocumentNotification = @"IBDidOpenDocumentNotification";
