@@ -34,9 +34,9 @@
 #ifndef INCLUDED_GormMenuItemAttributesInspector_h_
 #define INCLUDED_GormMenuItemAttributesInspector_h_
 
-#include <InterfaceBuilder/IBInspector.h>
+#include <InterfaceBuilder/InterfaceBuilder.h>
 
-@class NSTextField, NSPopUpButton;
+@class NSTextField, NSPopUpButton, NSMatrix;
 
 @interface GormMenuItemAttributesInspector : IBInspector
 {
@@ -44,6 +44,7 @@
   NSTextField	*shortCut;
   NSTextField	*tagText;
   NSPopUpButton *keyPopup;
+  NSMatrix	*keyType;
   id             altBtn;
   id             ctrlBtn;
   id             shiftBtn;
