@@ -35,14 +35,16 @@
 #ifndef	INCLUDED_GormWindowSizeInspector_h
 #define	INCLUDED_GormWindowSizeInspector_h
 
-#include <InterfaceBuilder/IBInspector.h>
+#include <InterfaceBuilder/InterfaceBuilder.h>
 
 @class NSButton;
 @class NSForm;
 
 @interface GormWindowSizeInspector : IBInspector
 {
+  NSForm *originForm;
   NSForm *sizeForm;
+  NSForm *autosaveName;
   NSForm *minForm;
   NSForm *maxForm;
 
