@@ -101,6 +101,47 @@ NSUInteger colsStepperValue;
   return self;
 }
 
+- (void) _refreshCellsComparingWithOldCells: (NSArray *)oldCells
+{
+  id<IBDocuments> document = [(id<IB>)NSApp activeDocument];
+  NSArray *newCells = [[self object] cells];
+  NSUInteger newCount = [newCells count];
+  NSUInteger oldCount = [oldCells count];
+  NSMutableArray *cellsAdded = [NSMutableArray arrayWithCapacity: newCount];
+  NSMutableArray *cellsRemoved = [NSMutableArray arrayWithCapacity: newCount];
+  NSEnumerator *en = nil;
+  NSCell *c = nil;
+
+  if (newCount > oldCount)
+    {
+      en = [newCells objectEnumerator];
+      while ((c = [en nextObject]) != nil)
+        {
+          if ([oldCells containsObject: c] == NO)
+            {
+              [cellsAdded addObject: c]; // object is new
+            }
+        }
+      [document attachObjects: cellsAdded toParent: [self object]];
+    }
+  else if (oldCount > newCount)
+    {
+      en = [oldCells objectEnumerator];
+      while ((c = [en nextObject]) != nil)
+        {
+          if ([newCells containsObject: c] == NO)
+            {
+              [cellsRemoved addObject: c]; // object is new
+            }
+        }
+      [document detachObjects: cellsRemoved closeEditors: NO];
+    }
+  else
+    {
+      NSLog(@"No change");
+    }
+}
+
 /* Commit changes that the user makes in the Attributes Inspector */
 - (void) ok: (id) sender
 {
@@ -149,19 +190,34 @@ NSUInteger colsStepperValue;
       NSInteger    tag;
       NSString     *title;
       int          c;
-      for (c = 0; c < [object numberOfColumns]; c++)
+
+      if ([object prototype] == nil)
         {
-	  int r;
-          for (r = 0; r < [object numberOfRows]; r++)
+          NSLog(@"prototype is nil, using first cell in matrix");
+          if ([object cells] > 0)
             {
-              cell = [object cellAtRow: r column: c];
-              tag = [cell tag];
-              title = [cell title];
-              cell = [[object prototype] copy];
-              [cell setTag: tag];
-              [cell setTitle: title];
-              [object putCell:cell atRow:r column:c];
-              [cell release];
+              NSCell *acell = [[object cells] objectAtIndex: 0];
+              [object setPrototype: acell];
+              NSLog(@"prototype set %@", acell);
+            }
+        }
+      
+      if ([object prototype] != nil)
+        {
+          for (c = 0; c < [object numberOfColumns]; c++)
+            {
+              int r;
+              for (r = 0; r < [object numberOfRows]; r++)
+                {
+                  cell = [object cellAtRow: r column: c];
+                  tag = [cell tag];
+                  title = [cell title];
+                  cell = [[object prototype] copy];
+                  [cell setTag: tag];
+                  [cell setTitle: title];
+                  [object putCell:cell atRow:r column:c];
+                  [cell release];
+                }
             }
         }
       [object deselectAllCells];
@@ -179,7 +235,8 @@ NSUInteger colsStepperValue;
     {
       int rows = [[rowsForm cellAtIndex: 0] intValue];
       int cols = [[colsForm cellAtIndex: 0] intValue];
-      int num;
+      int num = 0;
+      NSArray *oldCells = [NSArray arrayWithArray: [[self object] cells]];
 
       while((num = [object numberOfRows]) != rows)
 	{
@@ -205,11 +262,13 @@ NSUInteger colsStepperValue;
 	    }
 	}
       [self _displayObject: object resize: YES];
+      [self _refreshCellsComparingWithOldCells: oldCells];
     }
   else if(sender == rowsStepper)
     {
       int delta = [sender intValue] - rowsStepperValue;
       int num = [object numberOfRows];
+      NSArray *oldCells = [NSArray arrayWithArray: [[self object] cells]];
 
       while(delta > 0)
 	{
@@ -227,11 +286,13 @@ NSUInteger colsStepperValue;
       [sender setIntValue: num];
       rowsStepperValue = num;
       [self _displayObject: object resize: YES];
+      [self _refreshCellsComparingWithOldCells: oldCells];
     }
   else if(sender == colsStepper)
     {
       int delta = [sender intValue] - colsStepperValue;
       int num = [object numberOfColumns];
+      NSArray *oldCells = [NSArray arrayWithArray: [[self object] cells]];
 
       while(delta > 0)
 	{
@@ -249,6 +310,7 @@ NSUInteger colsStepperValue;
       [sender setIntValue: num];
       colsStepperValue = num;
       [self _displayObject: object resize: YES];
+      [self _refreshCellsComparingWithOldCells: oldCells];
     }
 
   /*
@@ -263,8 +325,8 @@ NSUInteger colsStepperValue;
     {
       [prototypeMatrix putCell: [object prototype] atRow:0 column:0];
     }
-  
-  [super ok:sender];
+
+   [super ok:sender];
 }
 
 
