@@ -22,15 +22,14 @@
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
 */
 #include <Foundation/Foundation.h>
-#include <AppKit/NSTableColumn.h>
-#include <AppKit/NSTabView.h>
-#include <AppKit/NSWindow.h>
-#include <AppKit/NSTabViewItem.h>
-#include <AppKit/NSScrollView.h>
+#include <AppKit/AppKit.h>
+
 #include <InterfaceBuilder/InterfaceBuilder.h>
+
 #include "GormNSBrowser.h"
 #include "GormNSTableView.h"
 #include "GormNSOutlineView.h"
+
 #include <math.h>
 
 
@@ -46,7 +45,7 @@
 @implementation ContainersPalette
 
 - (void) finishInstantiate
-{ 
+{
 
   NSView	   *contents;
   NSTableView      *tv;
@@ -60,6 +59,7 @@
 				       styleMask: NSBorderlessWindowMask 
 					 backing: NSBackingStoreRetained
 					   defer: NO];
+  [originalWindow setTitle: @"Containers"];
   contents = [originalWindow contentView];
 
 /*******************/
