@@ -26,6 +26,7 @@
 
 #include <Foundation/Foundation.h>
 #include <AppKit/AppKit.h>
+#include <InterfaceBuilder/InterfaceBuilder.h>
 
 #include <GormCore/GormCore.h>
 
@@ -57,7 +58,7 @@
 
 - (id) init
 {
-  if((self = [super init]) != nil)
+  if ((self = [super init]) != nil)
     {
       _repairLog = [[NSMutableArray alloc] init];
     }
@@ -75,7 +76,7 @@
   NSEnumerator *en = [_repairLog objectEnumerator];
   id m = nil;
 
-  if([NSBundle loadNibNamed: @"GormInconsistenciesPanel"
+  if ([NSBundle loadNibNamed: @"GormInconsistenciesPanel"
 	       owner: self] == NO)
     {
       NSLog(@"Failed to open message panel...");
@@ -125,10 +126,10 @@
     /*
      * Take care of any dangling menus...
      */
-    if([obj isKindOfClass: [NSMenu class]] && ![key isEqual: @"NSMenu"])
+    if ([obj isKindOfClass: [NSMenu class]] && ![key isEqual: @"NSMenu"])
       {
 	id sm = [obj supermenu];
-	if(sm == nil)
+	if (sm == nil)
 	  {
 	    NSArray *menus = findAll(obj);
 	    [_repairLog addObject: 
@@ -147,45 +148,19 @@
 	  }
       }
 
-    /*
-     * Take care of any dangling menu items...
-     */
-    /*
-    if([obj isKindOfClass: [NSMenuItem class]])
-      {
-	id m = [obj menu];
-	if(m == nil)
-	  {
-	    id sm = [obj submenu];
-
-	    [_repairLog addObject:
-			  [NSString stringWithFormat: @"ERROR ==> Found and removed an unattached menu item %@, %@.\n",
-				    obj, key]];
-	    [document detachObject: obj];
-
-	    // if there are any submenus, detach those as well.
-	    if(sm != nil)
-	      {
-		NSArray *menus = findAll(sm);
-		[document detachObjects: menus];
-	      }
-	    errorCount++;
-	  }
-      }
-    */
-
     /*
      * If there is a view which is not associated with a name, give it one...
      */
-    if([obj isKindOfClass: [NSWindow class]])
+    if ([obj isKindOfClass: [NSWindow class]])
       {
+        NSWindow *w = (NSWindow *)obj;
 	NSArray *allViews = allSubviews([obj contentView]);
 	NSEnumerator *ven = [allViews objectEnumerator];
 	id v = nil;
 
-	if([obj windowLevel] != NSNormalWindowLevel)
+	if ([w windowLevel] != NSNormalWindowLevel)
 	  {
-	    [obj setLevel: NSNormalWindowLevel];
+	    [w setLevel: NSNormalWindowLevel];
 	    [_repairLog addObject: 
 			  [NSString stringWithFormat: 
 				      @"ERROR ==> Found window %@ with an invalid level, correcting.\n", 
@@ -196,39 +171,42 @@
 	while((v = [ven nextObject]) != nil)
 	  {
 	    NSString *name = nil;
-
+            id target = nil;
+            SEL action = NULL;
+            BOOL isAction = NO;
+            
 	    // skip these...
-	    if([v isKindOfClass: [NSMatrix class]])
+	    if ([v isKindOfClass: [NSMatrix class]])
 	      {
 		[_repairLog addObject: @"INFO: Skipping NSMatrix view.\n"];
 		continue;
 	      }
-	    else if([v isKindOfClass: [NSScroller class]] &&
+	    else if ([v isKindOfClass: [NSScroller class]] &&
 		    [[v superview] isKindOfClass: [NSTextView class]])
 	      {
 		[_repairLog addObject: @"INFO: Skipping NSScroller in an NSTextView.\n"];
 		continue;
 	      }
-	    else if([v isKindOfClass: [NSScroller class]] &&
+	    else if ([v isKindOfClass: [NSScroller class]] &&
 		    [[v superview] isKindOfClass: [NSBrowser class]])
 	      {
 		[_repairLog addObject: @"INFO: Skipping NSScroller in an NSTextView.\n"];
 		continue;
 	      }
-	    else if([v isKindOfClass: [NSClipView class]] &&
+	    else if ([v isKindOfClass: [NSClipView class]] &&
 		    [[v superview] isKindOfClass: [NSTextView class]])
 	      {
 		[_repairLog addObject: @"INFO: Skipping NSClipView in an NSTextView.\n"];
 		continue;
 	      }
-	    else if([v isKindOfClass: [NSClipView class]] &&
+	    else if ([v isKindOfClass: [NSClipView class]] &&
 		    [[v superview] isKindOfClass: [NSBrowser class]])
 	      {
 		[_repairLog addObject: @"INFO: Skipping NSClipView in an NSTextView.\n"];
 		continue;
 	      }
-	       	    
-	    if((name = [document nameForObject: v]) == nil)
+
+	    if ((name = [document nameForObject: v]) == nil)
 	      {
 		[document attachObject: v toParent: [v superview]];
 		name = [document nameForObject: v];
@@ -236,12 +214,73 @@
 			      [NSString stringWithFormat: 
 					  @"ERROR ==> Found view %@ without an associated name, adding to the nametable as %@\n", 
 					v, name]];
-		if([v respondsToSelector: @selector(stringValue)])
+		if ([v respondsToSelector: @selector(stringValue)])
 		  {
 		    [_repairLog addObject: [NSString stringWithFormat: @"INFO: View string value is %@\n",[v stringValue]]];
 		  }
 		errorCount++;
 	      }
+
+            // Delete old target action settings if they are directly encoded.
+            if ([v respondsToSelector: @selector(setTarget:)])
+              {
+                target = [v target];
+                [v setTarget: nil]; // remove hard set targets or actions.
+		[_repairLog addObject: [NSString stringWithFormat:
+                                                          @"ERROR: Removing hard set target %@ on object %@.\n",
+                                                                      target, name]];
+                errorCount++;                
+              }
+
+            // delete action...
+            if ([v respondsToSelector: @selector(setAction:)])
+              {
+                action = [v action];
+                [v setAction: NULL]; // remove hard set targets or actions.
+		[_repairLog addObject: [NSString stringWithFormat:
+                                                          @"ERROR: Removing hard set action %@ on object %@.\n",
+                                                 NSStringFromSelector(action),
+                                                 name]];
+		errorCount++;                
+              }
+            
+            NSString *actionName = NSStringFromSelector(action);
+            isAction = [actionName containsString: @":"];
+            
+            // create control connector...
+            if (action != NULL && target != nil && isAction)
+              {
+                NSNibControlConnector *con = [[NSNibControlConnector alloc] init];
+                [con setDestination: name];
+                [con setLabel: actionName];
+                [document addConnector: con];
+                [document touch];
+                
+                [_repairLog addObject: [NSString stringWithFormat:
+                                                          @"FIX: Creating outlet connection for %@ on %@.\n",
+                                                 NSStringFromSelector(action),
+                                                 name]];
+                errorCount++;
+              }
+
+            // create outlet connector...
+            if (action != NULL && target != nil && !isAction)
+              {
+                NSString *actionName = NSStringFromSelector(action);
+                NSNibOutletConnector *con = [[NSNibOutletConnector alloc] init];
+                [con setDestination: name];
+                [con setLabel: actionName];
+                [document addConnector: con];
+                [document touch];
+                
+                [_repairLog addObject: [NSString stringWithFormat:
+                                                          @"FIX: Creating control connection for %@ on %@.\n",
+                                                 NSStringFromSelector(action),
+                                                 name]];
+                errorCount++;
+              }
+
+            
 	    [_repairLog addObject: [NSString stringWithFormat: @"INFO: Checking view %@ with name %@\n", v, name]];
 	  }
       }
@@ -256,19 +295,19 @@
     {
       id src = [con source];
       id dst = [con destination];
-      if([con isKindOfClass: [NSNibConnector class]])
+      if ([con isKindOfClass: [NSNibConnector class]])
 	{
-	  if(src == nil)
+	  if (src == nil)
 	    {
 	      [_repairLog addObject: 
 			    [NSString stringWithFormat: @"ERROR ==> Removing bad connector with nil source: %@\n",con]];
 	      [document removeConnector: con];
 	      errorCount++;
 	    }
-	  else if([src isKindOfClass: [NSString class]])
+	  else if ([src isKindOfClass: [NSString class]])
 	    {
 	      id obj = [document objectForName: src];
-	      if(obj == nil)
+	      if (obj == nil)
 		{
 		  [_repairLog addObject: 
 				[NSString stringWithFormat: 
@@ -278,10 +317,10 @@
 		  errorCount++;
 		}
 	    }
-	  else if([dst isKindOfClass: [NSString class]])
+	  else if ([dst isKindOfClass: [NSString class]])
 	    {
 	      id obj = [document objectForName: dst];
-	      if(obj == nil)
+	      if (obj == nil)
 		{
 		  [_repairLog addObject: 
 				[NSString stringWithFormat: 
@@ -295,7 +334,7 @@
     }
   
   // report the number of errors...
-  if(errorCount > 0)
+  if (errorCount > 0)
     {
       errorMsg = [NSString stringWithFormat: @"%d inconsistencies were found, please save the file.",errorCount]; 
       [self _openMessagePanel: errorMsg];
@@ -313,7 +352,7 @@
   id obj = nil;
   while((obj = [en nextObject]) != nil)
     {
-      if([obj isKindOfClass: cls])
+      if ([obj isKindOfClass: cls])
 	{
 	  return YES;
 	}
@@ -365,18 +404,18 @@
 	      while((key = [enumerator nextObject]) != nil)
 		{
 		  NSFileWrapper *fw = [fileWrappers objectForKey: key];
-		  if([fw isRegularFile])
+		  if ([fw isRegularFile])
 		    {
 		      NSData *fileData = [fw regularFileContents];
-		      if([key isEqual: @"objects.gorm"])
+		      if ([key isEqual: @"objects.gorm"])
 			{
 			  data = fileData;
 			}
-		      else if([key isEqual: @"data.info"])
+		      else if ([key isEqual: @"data.info"])
 			{
 			  [document setInfoData: fileData];
 			}
-		      else if([key isEqual: @"data.classes"])
+		      else if ([key isEqual: @"data.classes"])
 			{
 			  classes = fileData;
 			  
@@ -537,7 +576,7 @@
 		   * to the list so that they can be properly processed.
 		   */
 		  version = [u versionForClassName: NSStringFromClass([GSNibContainer class])];
-		  if(version == 0)
+		  if (version == 0)
 		    {
 		      id obj;
 		      NSEnumerator *en = [nt objectEnumerator];
@@ -545,7 +584,7 @@
 		      // get all of the GSNibItem subclasses which could be top level objects
 		      while((obj = [en nextObject]) != nil)
 			{
-			  if([obj isKindOfClass: [GSNibItem class]] &&
+			  if ([obj isKindOfClass: [GSNibItem class]] &&
 			     [obj isKindOfClass: [GSCustomView class]] == NO)
 			    {
 			      [[container topLevelObjects] addObject: obj];
@@ -553,7 +592,7 @@
 			}
 		      [document setOlderArchive: YES];
 		    }
-		  else if(version == 1)
+		  else if (version == 1)
 		    {
 		      // nothing else, just mark it as older...
 		      [document setOlderArchive: YES];
@@ -565,7 +604,7 @@
 		   * it was made by an older version of Gorm.
 		   */
 		  version = [u versionForClassName: NSStringFromClass([GSWindowTemplate class])];
-		  if(version == NSNotFound && [self _containsKindOfClass: [NSWindow class]])
+		  if (version == NSNotFound && [self _containsKindOfClass: [NSWindow class]])
 		    {
 		      [document setOlderArchive: YES];
 		    }
@@ -578,13 +617,11 @@
 		  /*
 		   * Repair the .gorm file, if needed.
 		   */
-		  /*
-		  if(repairFile)
+		  if (repairFile)
 		    {
 		      [self _repairFile];
 		    }
-		  */
-		  NSDebugLog(@"nameTable = %@",[container nameTable]);
+                  NSDebugLog(@"nameTable = %@",[container nameTable]);
 		  
 		  // awaken all elements after the load is completed.
 		  enumerator = [nt keyEnumerator];
